@@ -190,7 +190,7 @@ class RuntimeStateConfig(RuntimeStateConfigurationBase):
                          'git_sign_patch', 'serial_sphinx', 'package_path',
                          'clean_generated', 'include_mask', 'push_targets',
                          'dry_run', 't_corpora_config', 't_translate_config',
-                         't_output_file', 't_source', 't_target']
+                         't_output_file', 't_source', 't_target', 'port']
 
     def __init__(self, obj=None):
         super(RuntimeStateConfig, self).__init__(obj)
@@ -290,6 +290,14 @@ class RuntimeStateConfig(RuntimeStateConfigurationBase):
 
         self.state['builder'] = value
 
+    def is_publish_target(self):
+        if 'builder' not in self.state:
+            return False
+        elif 'publish' in self.state['builder']:
+            return True
+        else:
+            return False
+
     @property
     def git_objects(self):
         return self.state['git_objects']
